import Vue from "vue";
import axios from "axios";
import user from "@/store/modules/user";
import { Message } from "@/utils/message";
import md5 from "js-md5";
const instance = axios.create({
  baseURL: process.env.VUE_APP_BASE_API,
  timeout: 5000
});
const appKey = "cd72c223-923f-44a3-aede-b9f07dcd56b8";
const plat = "steelfurniture";
const v = "1.0";
instance.interceptors.request.use(
  ({ headers: { timestamp = Date.now(), ...h }, ...x }) => ({
    headers: {
      timestamp,
      appKey,
      plat,
      v,
      sign: md5(`timestamp${timestamp}plat${plat}v${v}appKey${appKey}`),
      ...h
    },
    ...x
  })
);

instance.interceptors.response.use(
  x => x,
  err => ({
    data: {
      code: -1,
      msg: "网络请求失败",
      data: err
    }
  })
);
const getResult: <T>(x: IBaseResult) => IResult<T> = <T>({
  data,
  msg,
  code
}: IBaseResult<T>) => {
  if (code === 0) return [null, data];
  Message.error(msg || "发生未知错误");
  return [{ msg, code }, (data || {}) as T];
};
export const post: IRequest = async <T>(url: string, params: any) => {
  const { data } = await instance.post<IBaseResult<T>>(url, params);
  return getResult<T>(data);
};
export const get: IRequest = async <T>(url: string, params: any) => {
  const { data } = await instance.get<IBaseResult<T>>(url, { params });
  return getResult<T>(data);
};
export const post_auth: IRequest = async <T>(url: string, params: any) =>
  await post<T>(url, Object.assign({}, params, { token: user.Token }));
export const get_auth: IRequest = async <T>(url: string, params: any) =>
  await get<T>(url, Object.assign({}, params, { token: user.Token }));
export default {
  install(vue: typeof Vue) {
    Object.assign(vue.prototype, {
      $get: get,
      $post: post,
      $get_auth: get_auth,
      $post_auth: post_auth
    });
  }
};
